@@ -63,12 +63,11 @@ class APIView(RouteView):
             if self.route is None:
                 self.route = self.plural_name or self.model._meta.verbose_name_plural or f"{self.model.__name__}s"
 
-            if not self.route.endswith("/"):
-                urlpatterns.append(path(f"{self.route}/", self.as_view(), name=self.name))
-                urlpatterns.append(path(f"{self.route}/<int:id>", self.as_view(), name=self.name))
-            else:
-                urlpatterns.append(path(self.route, self.as_view(), name=self.name))
-                urlpatterns.append(path(f"{self.route}<int:id>", self.as_view(), name=self.name))
+            self.route = f"{self.route.rstrip('/')}/"
+            urlpatterns.extend((
+                path(self.route, self.as_view(), name=self.name),
+                path(f"{self.route}<int:id>", self.as_view(), name=self.name)
+            ))
 
     def __init__(self, *args, **kwargs):
         if self.model is None:
@@ -126,7 +125,7 @@ class APIView(RouteView):
             except (KeyError, ObjectDoesNotExist):
                 return InvalidToken("Invalid body")
 
-            if not user.has_perm(f'api.{self.match_table[request.method]}_{self.verbose_name}') and not user.id == request.path_info.split('/')[-1].split('?')[0]:
+            if not user.has_perm(f'api.{self._permissions_match_table[request.method]}_{self.singular_name}') and not request.path_info.split("?")[0].strip("/").endswith(str(user.id)):
                 return NotAllowed()
 
         return super().dispatch(request, queryset, id)
